MismatchTasksReturnsException class
Thrown when tasks sharing the same taskId attempt to return incompatible types.
A task must always return values of the same expected type across executions.
- Implemented types
Constructors
- MismatchTasksReturnsException({required String taskId, required Type? typeA, required Type? typeB})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId → String
-
Identifier of the task whose return types are conflicting.
final
- typeA → Type?
-
The mismatching expected types detected for the conflicting tasks.
final
- typeB → Type?
-
The mismatching expected types detected for the conflicting tasks.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited